@@ -241,7 +241,7 @@ ECItoKOE <- function(position_ECI, velocity_ECI) {
         lonPer <- NaN
     }
     # true longitude - circular equatorial orbits
-    if((sqrt(sum(position_ECI)) > eps) & orbitType == "ce") {
+    if((sqrt(sum(position_ECI^2)) > eps) & orbitType == "ce") {
         cosTrueLon <- position_ECI[1] / sqrt(sum(position_ECI))
         if(abs(cosTrueLon) > 1) {
             cosTrueLon <- sign(cosTrueLon)
@@ -288,11 +288,11 @@ ECItoKOE <- function(position_ECI, velocity_ECI) {
         semiMajorAxis = a,
         eccentricity = e,
         inclination = i,
-        meanAnomaly = m,
-        argumentPerigee = omega,
+        meanAnomaly = as.vector(m),
+        argumentPerigee = as.vector(omega),
         longitudeAscendingNode = OMEGA,
-        trueAnomaly = nu,
-        argumentLatitude = arglat,
+        trueAnomaly = as.vector(nu),
+        argumentLatitude = as.vector(arglat),
         longitudePerigee = lonPer,
         trueLongitude = trueLon
     ))
