@@ -40,6 +40,19 @@ italsat2_TLE
 
 test_TLEs[[17]]$inclination == italsat2_TLE$inclination
 
+## ----tidy = TRUE--------------------------------------------------------------
+# Read the provided test RINEX navigation files for both GPS and GLONASS:
+
+testGPSnav <- readGPSNavigationRINEX(paste0(path.package("asteRisk"), 
+"/testGPSRINEX.txt"))
+testGLONASSnav <- readGLONASSNavigationRINEX(paste0(path.package("asteRisk"), 
+"/testGLONASSRINEX.txt"))
+
+# Count the number of positional messages in each file:
+
+length(testGPSnav$messages)
+length(testGLONASSnav$messages)
+
 ## ----tidy = TRUE--------------------------------------------------------------
 # Element 11 of the set of test TLE contains an orbital state vector for
 # satellite MOLNIYA 1-83, launched from the USSR in 1992 and decayed in 2007
@@ -80,43 +93,44 @@ colnames(results_position_matrix) <- c("x", "y", "z", "time")
 
 last_molniya_propagation$algorithm
 
-# We can visualize the resulting trajectory using a plotly animation to confirm
-# that indeed a full revolution was completed and that the orbit is highly
-# eccentric.
-
-library(plotly)
-library(lazyeval)
-library(dplyr)
-
-# In order to create the animation, we must first define a function to create
-# the accumulated dataframe required for the animation
-
-accumulate_by <- function(dat, var) {
-    var <- f_eval(var, dat)
-    lvls <- plotly:::getLevels(var)
-    dats <- lapply(seq_along(lvls), function(x) {
-        cbind(dat[var %in% lvls[seq(1, x)], ], frame = lvls[[x]])
-    })
-    bind_rows(dats)
-}
-
-accumulated_df <- accumulate_by(as.data.frame(results_position_matrix), ~time)
-
-orbit_animation <- plot_ly(accumulated_df, x = ~x, y=~y, z=~z, type = "scatter3d",
-                           mode="marker", opacity=0.8, line=list(width = 6, 
-                                                                 color = ~time, 
-                                                                 reverscale = FALSE), 
-                           frame= ~frame)
-
-orbit_animation <- animation_opts(orbit_animation, frame=50)
-
-orbit_animation <- layout(orbit_animation, scene = list(
-    xaxis=list(range=c(min(results_position_matrix[,1]), max(results_position_matrix[,1]))),
-    yaxis=list(range=c(min(results_position_matrix[,2]), max(results_position_matrix[,2]))),
-    zaxis=list(range=c(min(results_position_matrix[,3]), max(results_position_matrix[,3])))
-))
-
-orbit_animation
+## ----tidy = TRUE, eval = FALSE------------------------------------------------
+#  # We can visualize the resulting trajectory using a plotly animation to confirm
+#  # that indeed a full revolution was completed and that the orbit is highly
+#  # eccentric.
+#  
+#  library(plotly)
+#  library(lazyeval)
+#  library(dplyr)
+#  
+#  # In order to create the animation, we must first define a function to create
+#  # the accumulated dataframe required for the animation
+#  
+#  accumulate_by <- function(dat, var) {
+#      var <- f_eval(var, dat)
+#      lvls <- plotly:::getLevels(var)
+#      dats <- lapply(seq_along(lvls), function(x) {
+#          cbind(dat[var %in% lvls[seq(1, x)], ], frame = lvls[[x]])
+#      })
+#      bind_rows(dats)
+#  }
+#  
+#  accumulated_df <- accumulate_by(as.data.frame(results_position_matrix), ~time)
+#  
+#  orbit_animation <- plot_ly(accumulated_df, x = ~x, y=~y, z=~z, type = "scatter3d",
+#                             mode="marker", opacity=0.8, line=list(width = 6,
+#                                                                   color = ~time,
+#                                                                   reverscale = FALSE),
+#                             frame= ~frame)
+#  
+#  orbit_animation <- animation_opts(orbit_animation, frame=50)
+#  
+#  orbit_animation <- layout(orbit_animation, scene = list(
+#      xaxis=list(range=c(min(results_position_matrix[,1]), max(results_position_matrix[,1]))),
+#      yaxis=list(range=c(min(results_position_matrix[,2]), max(results_position_matrix[,2]))),
+#      zaxis=list(range=c(min(results_position_matrix[,3]), max(results_position_matrix[,3])))
+#  ))
+#  
+#  orbit_animation
 
 ## ----tidy = TRUE--------------------------------------------------------------
 # Let us convert the last propagation previously calculated for the MOLNIYA 1-83
@@ -161,68 +175,68 @@ ggmap(get_map(c(left=-180, right=180, bottom=-80, top=80))) +
              color="blue", size=0.3, alpha=0.8)
 
 ## ----tidy = TRUE, eval = evaluateExtraChunks----------------------------------
-# The HPOP requires as input the satellite mass, the effective areas subjected
-# to solar radiation pressure and atmospheric drag, and the drag and
-# reflectivity coefficients. 
-# The mass and cross-section of Molniya satellites are approximately 1600 kg and
-# 15 m2, respectively. We will use the cross-section to approximate the
-# effective areafor both atmospheric drag and radiation pressure.
-# Regarding the drag and reflectivity coefficients, while their values vary
-# for each satellite and orbit, 2.2 and 1.2 respectively can be used as
-# approximations.
-
-molniyaMass <- 1600
-molniyaCrossSection <- 15
-molniyaCd <- 2.2
-molniyaCr <- 1.2
-
-# As initial conditions, we will use the initial conditions provided in the
-# same TLE for MOLNIYA 1-83 used previously for the SGP4/SDP4 propagator.
-# We first need to calculate the initial position and velocity in the GCRF
-# ECI frame of reference from the provided orbital elements. 
-# As an approximation, we will use the results obtained for t = 0 with the
-# SGP4/SDP4 propagator. We convert those into the GCRF frame of reference.
-# It should be noted that such an approximation introduces an error due to
-# a mismatch between the position derivative calculated at each propagation
-# point through SGP4/SDP4 and the actual velocity of the satellite.
-
-GCRF_coordinates <- TEMEtoGCRF(results_position_matrix[1,1:3],
-                               results_velocity_matrix[1,1:3], 
-                               molniya$dateTime)
-
-initialPosition <- GCRF_coordinates$position*1000
-initialVelocity <- GCRF_coordinates$velocity*1000
-
-# Let´s use the HPOP to calculate the position each 2 minutes during a period
-# of 3 hours
-
-targetTimes <- seq(0, 10800, by=120)
-
-hpop_results <- hpop(initialPosition, initialVelocity, molniya$dateTime,
-                     targetTimes, molniyaMass, molniyaCrossSection,
-                     molniyaCrossSection, molniyaCr, molniyaCd)
-
-# Now we can calculate and plot the corresponding geodetic coordinates
-
-geodetic_matrix_hpop <- matrix(nrow=nrow(hpop_results), ncol=3)
-
-for(i in 1:nrow(geodetic_matrix_hpop)) {
-    new_dateTime <- as.character(as.POSIXct(molniya$dateTime, tz="UTC") + targetTimes[i])
-    new_geodetic <- GCRFtoLATLON(hpop_results[i, 2:4], new_dateTime)
-    geodetic_matrix_hpop[i,] <- new_geodetic
-}
-
-colnames(geodetic_matrix_hpop) <- c("latitude", "longitude", "altitude")
-
-library(ggmap)
-
-ggmap(get_map(c(left=-180, right=180, bottom=-80, top=80))) +
-  geom_segment(data=as.data.frame(geodetic_matrix_hpop), 
-               aes(x=longitude, y=latitude, 
-                   xend=c(tail(longitude, n=-1), NA), 
-                   yend=c(tail(latitude, n=-1), NA)), 
-               na.rm=TRUE) +
-  geom_point(data=as.data.frame(geodetic_matrix_hpop), aes(x=longitude, y=latitude), 
-             color="blue", size=0.3, alpha=0.8)
-
+#  # The HPOP requires as input the satellite mass, the effective areas subjected
+#  # to solar radiation pressure and atmospheric drag, and the drag and
+#  # reflectivity coefficients.
+#  # The mass and cross-section of Molniya satellites are approximately 1600 kg and
+#  # 15 m2, respectively. We will use the cross-section to approximate the
+#  # effective areafor both atmospheric drag and radiation pressure.
+#  # Regarding the drag and reflectivity coefficients, while their values vary
+#  # for each satellite and orbit, 2.2 and 1.2 respectively can be used as
+#  # approximations.
+#  
+#  molniyaMass <- 1600
+#  molniyaCrossSection <- 15
+#  molniyaCd <- 2.2
+#  molniyaCr <- 1.2
+#  
+#  # As initial conditions, we will use the initial conditions provided in the
+#  # same TLE for MOLNIYA 1-83 used previously for the SGP4/SDP4 propagator.
+#  # We first need to calculate the initial position and velocity in the GCRF
+#  # ECI frame of reference from the provided orbital elements.
+#  # As an approximation, we will use the results obtained for t = 0 with the
+#  # SGP4/SDP4 propagator. We convert those into the GCRF frame of reference.
+#  # It should be noted that such an approximation introduces an error due to
+#  # a mismatch between the position derivative calculated at each propagation
+#  # point through SGP4/SDP4 and the actual velocity of the satellite.
+#  
+#  GCRF_coordinates <- TEMEtoGCRF(results_position_matrix[1,1:3],
+#                                 results_velocity_matrix[1,1:3],
+#                                 molniya$dateTime)
+#  
+#  initialPosition <- GCRF_coordinates$position*1000
+#  initialVelocity <- GCRF_coordinates$velocity*1000
+#  
+#  # Let´s use the HPOP to calculate the position each 2 minutes during a period
+#  # of 3 hours
+#  
+#  targetTimes <- seq(0, 10800, by=120)
+#  
+#  hpop_results <- hpop(initialPosition, initialVelocity, molniya$dateTime,
+#                       targetTimes, molniyaMass, molniyaCrossSection,
+#                       molniyaCrossSection, molniyaCr, molniyaCd)
+#  
+#  # Now we can calculate and plot the corresponding geodetic coordinates
+#  
+#  geodetic_matrix_hpop <- matrix(nrow=nrow(hpop_results), ncol=3)
+#  
+#  for(i in 1:nrow(geodetic_matrix_hpop)) {
+#      new_dateTime <- as.character(as.POSIXct(molniya$dateTime, tz="UTC") + targetTimes[i])
+#      new_geodetic <- GCRFtoLATLON(hpop_results[i, 2:4], new_dateTime)
+#      geodetic_matrix_hpop[i,] <- new_geodetic
+#  }
+#  
+#  colnames(geodetic_matrix_hpop) <- c("latitude", "longitude", "altitude")
+#  
+#  library(ggmap)
+#  
+#  ggmap(get_map(c(left=-180, right=180, bottom=-80, top=80))) +
+#    geom_segment(data=as.data.frame(geodetic_matrix_hpop),
+#                 aes(x=longitude, y=latitude,
+#                     xend=c(tail(longitude, n=-1), NA),
+#                     yend=c(tail(latitude, n=-1), NA)),
+#                 na.rm=TRUE) +
+#    geom_point(data=as.data.frame(geodetic_matrix_hpop), aes(x=longitude, y=latitude),
+#               color="blue", size=0.3, alpha=0.8)
+#  
 
